@@ -41,7 +41,7 @@ class PlusBatch():
         self.cds_batchid = str(uuid.uuid4())
         self.number_of_files = 0
         self.state = 'Init'
-        self.business_object_type=business_object_type
+        self.business_object_type=str(business_object_type).lower()
 
         self.service_name=f'plus-bi-{business_object_type}-onramp-storageblob'
         self.message_type=f'plus-bi-{business_object_type}'
@@ -65,36 +65,13 @@ class PlusBatch():
     
     def _has_correct_filename(self):
         # check if filename contains a year, a period and the expected businesstype
+        #how to handle IIB: 2021_05_18_cds_pos01_cds_digitalreceipt_08ac77bd-fff7-4a8a-b20a-67600250c549.json
+
         logging.info(f'Checking if filename ({self.source_filename}) is valid.')
                 
         filenamearray = self.source_filename.split('_')
-
-        if len(filenamearray) < 3:
-            return False
-
-        self.year = filenamearray[0]
-        try: 
-            year = int(filenamearray[0])
-            if year < 2099 and year >= 2000:
-                logging.info('Valid year provided in filename.')
-        except Exception as e:
-            logging.error(f'{e}: {year} is not a valid year in {self.source_filename}')
-        
-        self.period = filenamearray[1]
-        try: 
-            if not self.period.startswith(('P','W','M')):
-                raise AssertionError(f'Unexpected value where period is expected in filename. Value: {self.period}, should start with "P"(Period),"W"(week) or"M"(Month).')
-        except Exception as e:
-            logging.error(f'{e}: {self.period} is not a valid period in {self.source_filename}')
-        
-        businesstype = str(filenamearray[2]).lower()
-        if self.business_object_type == '':
-            raise AssertionError(f'Business Object Type not set, first use method "set_business_object_type(self, business_object_type)" in this Class.')
-        if not businesstype.startswith(self.business_object_type):
-            logging.error(f'{businesstype} is not of the expected value: {self.business_object_type}')
-            return False
-        
         file_extension_array = self.source_filename.split('.')
+
         if isinstance(file_extension_array, (list, tuple)):
             self.file_extension=str(file_extension_array[-1]).lower()
         elif isinstance(file_extension_array, str):
@@ -104,13 +81,49 @@ class PlusBatch():
             logging.info(f'Unexpected type for file_extension_array: {type(file_extension_array)}')
             return False
 
+        if len(filenamearray) < 3:
+            logging.info('Shape of incoming filename is unexpected, filename is NOT valid.')
+            return False
+        elif len(filenamearray[0]) == 4 and len(filenamearray[1]) == 2 and len(filenamearray[2]) == 2 and filenamearray[-1].endswith("json"):
+            #this looks like an IIB message, we don't grab information for the onramp for these messages and so we need to set them ourself.
+            logging.info('Looks like an IIB filename.')
+            self.year = filenamearray[0]
+            #we can't grab the period from the filename in IIB-flows, we set it to Period 99 which is non-existent in practice.
+            self.period = 'P99'
+            #there is a test later on where we determine if the correct businessobject was passed, in non-IIB flows we grab the 
+            #businessobject from the filename to check if they match, here we set the value to itself.
+            businesstype = self.business_object_type
+        else:
+            self.year = filenamearray[0]
+            self.period = filenamearray[1]
+            businesstype = str(filenamearray[2]).lower()
+
+        try: 
+            year = int(filenamearray[0])
+            if year < 2099 and year >= 2000:
+                logging.info('Valid year provided in filename.')
+        except Exception as e:
+            logging.error(f'{e}: {year} is not a valid year in {self.source_filename}')        
+        
+        try: 
+            if not self.period.startswith(('P','W','M')):
+                raise AssertionError(f'Unexpected value where period is expected in filename. Value: {self.period}, should start with "P"(Period),"W"(week) or"M"(Month).')
+        except Exception as e:
+            logging.error(f'{e}: {self.period} is not a valid period in {self.source_filename}')        
+        
+        if self.business_object_type == '':
+            raise AssertionError(f'Business Object Type not set, first use method "set_business_object_type(self, business_object_type)" in this Class.')
+        if not businesstype.lower().startswith(self.business_object_type):
+            logging.error(f'{businesstype} is not of the expected value: {self.business_object_type}')
+            return False
+
         return True
 
     def _set_storage_info(self):
         self.source_filename=self.url.split('/')[-1]
 
         if not self._has_correct_filename():
-            raise AssertionError(f'Filename is not as expected.\nFilename should be in format "YYYY_PXX_BusinessObjectType.FileExt".')
+            raise AssertionError(f'Filename is not as expected. See previous messages...')
 
         self.source_url_account=plus_helper.split_custom_char(self.url, '/', 3)
         self.source_account=self.source_url_account.split('.')[0].split('/')[-1]
